<?php

/*************************************************************************
 * Username Change - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\UsernameChange\XF\Pub\Controller;

use XF\Mvc\ParameterBag;

class Member extends XFCP_Member
{

    public function actionUsernameLogs(ParameterBag $params)
    {
        /** @var \XenConcept\UsernameChange\XF\Entity\User $user */
        $user = $this->assertViewableUser($params->user_id);

        if (!$user->canViewLogsUsername($error))
        {
            return $this->noPermission($error);
        }

        $usernameLogs = $this->getChangeLogRepo()->findChangeLogs($user);

        $viewParams = [
            'user' => $user,
            'usernameLogs' => $usernameLogs
        ];

        return $this->view('XenConcept\UsernameChange:Member\UsernameLogs', 'xc_username_change_username_logs', $viewParams);
    }

    public function actionUsernameLogsClear(ParameterBag $params)
    {
        /** @var \XenConcept\UsernameChange\XF\Entity\User $user */
        $user = $this->assertViewableUser($params->user_id);

        if (!$user->canClearLogsUsername())
        {
            return $this->noPermission();
        }

        if ($this->isPost())
        {
            $changeLogRepo = $this->getChangeLogRepo();

            $changeLogRepo->clearLogs($user->user_id);

            return $this->redirect($this->buildLink('members', $user));
        }
        else
        {

            $viewParams = [
                'user' => $user
            ];

            return $this->view('XenConcept\UsernameChange:ChangeUsername\ClearLogs', 'xc_change_username_clear_logs', $viewParams);
        }
    }

    /**
     * @return \XenConcept\UsernameChange\Repository\ChangeLog
     */
    protected function getChangeLogRepo()
    {
        return $this->repository('XenConcept\UsernameChange:ChangeLog');
    }
}